// $Id: TunnelAttributesModel.cpp,v 1.10 2014/02/18 15:15:56 hupereir Exp $

/******************************************************************************
*
* Copyright (C) 2002 Hugo PEREIRA <mailto: hugo.pereira@free.fr>
*
* This is free software; you can redistribute it and/or modify it under the
* terms of the GNU General Public License as published by the Free Software
* Foundation; either version 2 of the License, or (at your option) any later
* version.
*
* This software is distributed in the hope that it will be useful, but WITHOUT
* Any WARRANTY; without even the implied warranty of MERCHANTABILITY or
* FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
* for more details.
*
* You should have received a copy of the GNU General Public License along with
* this program.  If not, see <http://www.gnu.org/licenses/>.
*
*******************************************************************************/

#include "Debug.h"
#include "TunnelAttributesModel.h"
#include "TunnelAttributesModel.moc"

//_______________________________________________
const QString TunnelAttributesModel::columnTitles_[ TunnelAttributesModel::nColumns ] =
{
    tr( "Local Port" ),
    tr( "Host" ),
    tr( "Remote Port" )
};

//______________________________________________________________________
QVariant TunnelAttributesModel::data( const QModelIndex& index, int role ) const
{
    Debug::Throw( "TunnelAttributesModel::data.\n" );

    // check index, role and column
    if( !index.isValid() ) return QVariant();

    // retrieve associated file info
    const TunnelAttributes& attributes( get()[index.row()] );

    // return text associated to file and column
    if( role == Qt::DisplayRole ) {

        switch( index.column() )
        {
            case LocalPort: return attributes.localPort();
            case Host: return attributes.host();
            case RemotePort: return attributes.remotePort();
            default: return QVariant();
        }

    }

    return QVariant();

}

//______________________________________________________________________
QVariant TunnelAttributesModel::headerData(int section, Qt::Orientation orientation, int role ) const
{

    if(
        orientation == Qt::Horizontal &&
        role == Qt::DisplayRole &&
        section >= 0 &&
        section < nColumns )
    { return columnTitles_[section]; }

    // return empty
    return QVariant();

}
